from setuptools import setup

setup(
    name='conflict_yaroslav2131234',
    version='0.1.0',
    description='A conflict Python package',
    author='Yaroslav Yaroslav',
    packages=['source'],
    install_requires=['numpy>=1.21.0']
)
